"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var libs_1 = require("./libs");
exports.compact = function (value) {
    return libs_1.R.pipe(libs_1.R.reject(libs_1.R.isNil), libs_1.R.reject(libs_1.R.isEmpty))(value);
};
exports.isPlainObject = function (value) {
    if (libs_1.R.is(Object, value) === false) {
        return false;
    }
    var ctr = value.constructor;
    if (typeof ctr !== 'function') {
        return false;
    }
    var prot = ctr.prototype;
    if (libs_1.R.is(Object, prot) === false) {
        return false;
    }
    if (prot.hasOwnProperty('isPrototypeOf') === false) {
        return false;
    }
    return true;
};
exports.isBlank = function (value) {
    if (value === null || value === undefined) {
        return true;
    }
    if (libs_1.R.is(Array, value) && exports.compact(value).length === 0) {
        return true;
    }
    if (libs_1.R.is(String, value) && value.trim() === '') {
        return true;
    }
    return false;
};
exports.isNumeric = function (value) {
    if (exports.isBlank(value)) {
        return false;
    }
    var num = parseFloat(value);
    if (num === undefined) {
        return false;
    }
    if (num.toString().length !== value.toString().length) {
        return false;
    }
    return !Number.isNaN(num);
};
exports.toNumber = function (value) {
    if (exports.isBlank(value)) {
        return value;
    }
    var num = parseFloat(value);
    if (num === undefined) {
        return value;
    }
    if (num.toString().length !== value.toString().length) {
        return value;
    }
    return Number.isNaN(num) ? value : num;
};
exports.toBool = function (value, defaultValue) {
    if (defaultValue === void 0) { defaultValue = undefined; }
    if (libs_1.R.isNil(value)) {
        return defaultValue;
    }
    if (libs_1.R.is(Boolean, value)) {
        return value;
    }
    var asString = value
        .toString()
        .trim()
        .toLowerCase();
    if (asString === 'true') {
        return true;
    }
    if (asString === 'false') {
        return false;
    }
    return defaultValue;
};
exports.toType = function (value) {
    if (!libs_1.R.is(String, value)) {
        return value;
    }
    var lowerCase = value.toLowerCase().trim();
    if (lowerCase === 'true') {
        return true;
    }
    if (lowerCase === 'false') {
        return false;
    }
    var num = exports.toNumber(lowerCase);
    if (libs_1.R.is(Number, num)) {
        return num;
    }
    return value;
};
//# sourceMappingURL=util.js.map